@@ -2,15 +2,18 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 
-import sys, os
+import sys
+import os
 DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
     '..', '..', '..', '..', '..', 'trytond')))
 if os.path.isdir(DIR):
     sys.path.insert(0, os.path.dirname(DIR))
 
 import unittest
+import doctest
 import trytond.tests.test_tryton
 from trytond.tests.test_tryton import test_view, test_depends
+from trytond.backend.sqlite.database import Database as SQLiteDatabase
 
 
 class PurchaseInvoiceLineStandaloneTestCase(unittest.TestCase):
@@ -34,10 +37,25 @@ class PurchaseInvoiceLineStandaloneTestCase(unittest.TestCase):
         '''
         test_depends()
 
+
+def doctest_dropdb(test):
+    database = SQLiteDatabase().connect()
+    cursor = database.cursor(autocommit=True)
+    try:
+        database.drop(cursor, ':memory:')
+        cursor.commit()
+    finally:
+        cursor.close()
+
+
 def suite():
     suite = trytond.tests.test_tryton.suite()
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
             PurchaseInvoiceLineStandaloneTestCase))
+    suite.addTests(doctest.DocFileSuite(
+            'scenario_purchase_invoice_line_standalone.rst',
+            setUp=doctest_dropdb, tearDown=doctest_dropdb, encoding='UTF-8',
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     return suite
 
 if __name__ == '__main__':
